@@ -10,9 +10,9 @@ import json
 import numpy as np
 from .db import Saveable, PlaceHolderObject
 from .data_series import DataSeries, TimeSeries, ValueSeries
-from ixdat.projects.samples import Sample
-from ixdat.projects.lablogs import LabLog
-from ixdat.exporters.csv_exporter import CSVExporter
+from .projects.samples import Sample
+from .projects.lablogs import LabLog
+from .exporters.csv_exporter import CSVExporter
 from .exceptions import BuildError, SeriesNotFoundError  # , TechniqueError
 
 
@@ -143,11 +143,11 @@ class Measurement(Saveable):
         else:
             # Normally, we're going to want to make sure that we're in
             technique_class = cls
-        try:
-            measurement = technique_class(**obj_as_dict)
-        except Exception:
-            raise
-        return measurement
+
+        if technique_class is cls:
+            return cls(**obj_as_dict)
+        else:  # Then its from_dict() might have more than ours:
+            return technique_class.from_dict(obj_as_dict)
 
     @classmethod
     def read(cls, path_to_file, reader, **kwargs):
@@ -428,7 +428,9 @@ class Measurement(Saveable):
                 s = append_series(ss)
         else:
             raise SeriesNotFoundError(f"{self} has no series called {item}")
-        return time_shifted(s, self.tstamp)
+        if hasattr(s, "tstamp") and not s.tstamp == self.tstamp:
+            s = time_shifted(s, self.tstamp)
+        return s
 
     def __setitem__(self, series_name, series):
         """Append `series` with name=`series_name` to `series_list` and remove others."""
@@ -474,7 +476,7 @@ class Measurement(Saveable):
         tseries = vseries.tseries
         v = vseries.data
         t = tseries.data + tseries.tstamp - self.tstamp
-        if tspan:
+        if tspan is not None:  # np arrays don't boolean well :(
             if include_endpoints:
                 if t[0] < tspan[0]:  # then add a point to include tspan[0]
                     v_0 = np.interp(tspan[0], t, v)
@@ -523,11 +525,9 @@ class Measurement(Saveable):
         if not self._plotter:
             from .plotters import ValuePlotter
 
+            # FIXME: I had to import here to avoid running into circular import issues
+
             self._plotter = ValuePlotter(measurement=self)
-        # self.plot_measurement.__doc__ = self._plotter.plot_measurement.__doc__
-        # self.plot.__doc__ = self._plotter.plot_measurement.__doc__
-        # FIXME: Help! plot_measurement() needs to be wrapped with the plotter's
-        # plot_measu
         return self._plotter
 
     @property
@@ -681,8 +681,8 @@ class Measurement(Saveable):
         can be single acceptable values or lists of acceptable values. In the latter
         case, each acceptable value is selected for on its own and the resulting
         measurements added together.
-        # FIXME: That is sloppy because it mutliplies the number of DataSeries
-            containing the same amount of data.
+        FIXME: That is sloppy because it multiplies the number of DataSeries
+        FIXME:  containing the same amount of data.
         If no key-word is given, the series name is assumed to
         be the default selector, which is named by self.sel_str. Multiple criteria are
         applied sequentially, i.e. you get the intersection of satisfying parts.
@@ -693,6 +693,7 @@ class Measurement(Saveable):
             kwargs (dict): Each key-word arguments is understood as the name
                 of a series and its acceptable value(s).
         """
+
         if len(args) >= 1:
             if not self.sel_str:
                 raise BuildError(
@@ -717,7 +718,7 @@ class Measurement(Saveable):
         return new_measurement
 
     def select(self, *args, tspan=None, **kwargs):
-        """`cut` (with tspan) and `select_values` (with *args and/or **kwargs)."""
+        """`cut` (with tspan) and `select_values` (with args and/or kwargs)."""
         new_measurement = self
         if tspan:
             new_measurement = new_measurement.cut(tspan=tspan)
@@ -727,7 +728,7 @@ class Measurement(Saveable):
 
     @property
     def tspan(self):
-        """Return (t_start, t_finish) for all data in the measurement"""
+        """Return `(t_start, t_finish)` interval including all data in the measurement"""
         t_start = None
         t_finish = None
         for tcol in self.time_names:
@@ -756,6 +757,7 @@ class Measurement(Saveable):
         all the raw series (or their placeholders) are just stored in the lists.
         TODO: Make sure with tests this is okay, differentiate using | operator if not.
         """
+
         # First we prepare a dictionary for all but the series_list.
         # This has both dicts, but prioritizes self's dict for all that appears twice.
         obj_as_dict = self.as_dict()
@@ -790,6 +792,22 @@ class Measurement(Saveable):
         )
         return cls.from_dict(obj_as_dict)
 
+    def join(self, other, join_on=None):
+        """Join two measurements based on a shared data series
+
+        This involves projecting all timeseries from other's data series so that the
+        variable named by `join_on` is shared between all data series.
+        This is analogous to an explicit inner join.
+
+        Args:
+            other (Measurement): a second measurement to join to self
+            join_on (str or tuple): Either a string, if the value to join on is called
+                the same thing in both measurements, or a tuple of two strings if it is
+                not.
+                The variable described by join_on must be monotonically increasing in
+                both measurements.
+        """
+
 
 #  ------- Now come a few module-level functions for series manipulation ---------
 # TODO: move to an `ixdat.build` module or similar.
