@@ -20,9 +20,12 @@ from .pfeiffer import PVMassSpecReader
 from .cinfdata import CinfdataTXTReader
 
 # ec-ms
-from .zilien import ZilienTSVReader, ZilienTMPReader
+from .zilien import ZilienTSVReader, ZilienTMPReader, ZilienSpectrumReader
 from .ec_ms_pkl import EC_MS_CONVERTER
 
+# spectroelectrochemistry
+from .msrh_sec import MsrhSECReader, MsrhSECDecayReader
+
 READER_CLASSES = {
     "ixdat": IxdatCSVReader,
     "biologic": BiologicMPTReader,
@@ -32,5 +35,8 @@ READER_CLASSES = {
     "cinfdata": CinfdataTXTReader,
     "zilien": ZilienTSVReader,
     "zilien_tmp": ZilienTMPReader,
+    "zilien_spec": ZilienSpectrumReader,
     "EC_MS": EC_MS_CONVERTER,
+    "msrh_sec": MsrhSECReader,
+    "msrh_sec_decay": MsrhSECDecayReader,
 }
