@@ -116,10 +116,7 @@ class BiologicMPTReader:
                 f"This reader only works for files with a '{t_str}' column"
             )
         tseries = TimeSeries(
-            name=t_str,
-            data=self.column_data[t_str],
-            tstamp=self.tstamp,
-            unit_name="s",
+            name=t_str, data=self.column_data[t_str], tstamp=self.tstamp, unit_name="s",
         )
         data_series_list = [tseries]
         for column_name, data in self.column_data.items():
@@ -235,9 +232,12 @@ def get_column_unit(column_name):
     return unit_name
 
 
+# Formats by which timestamps are saved in various EC-Labs # with example encountered
 BIOLOGIC_TIMESTAMP_FORMS = (
-    "%m/%d/%Y %H:%M:%S",  # like 07/29/2020 10:31:03
     "%m-%d-%Y %H:%M:%S",  # like 01-31-2020 10:32:02
+    "%m/%d/%Y %H:%M:%S",  # like 07/29/2020 10:31:03
+    "%m-%d-%Y %H:%M:%S.%f",  # (not seen yet)
+    "%m/%d/%Y %H:%M:%S.%f",  # like 04/27/2021 11:35:39.227 (EC-Lab v11.34)
 )
 
 # This tuple contains variable names encountered in .mpt files. The tuple can be used by
@@ -305,8 +305,7 @@ if __name__ == "__main__":
     )
 
     ec_measurement = Measurement.read(
-        reader="biologic",
-        path_to_file=path_to_test_file,
+        reader="biologic", path_to_file=path_to_test_file,
     )
 
     t, v = ec_measurement.grab_potential(tspan=[0, 100])
